@@ -79,7 +79,8 @@ class MYSQLExporter(Result):
 
     def save(self, query, args, status=True):
         try:
-            print args
+            if self.args.get_only_ff:
+                args=[args[0], args[1])
             self.sqlconn.cursor().execute(query %tuple(args))
             self.sqlconn.commit()
 
